@@ -1,23 +1,9 @@
-/***************************************************************************
-                          kmousetool.cpp  -  description
-                             -------------------
-    begin                : Sun Jan 20 23:27:58 PST 2002
-    copyright            : (C) 2002-2003 by Jeff Roush
-    email                : jeff@mousetool.com
-    copyright            : (C) 2003 by Olaf Schmidt
-    email                : ojschmidt@kde.org
-    copyright            : (C) 2003 by Gunnar Schmi Dt
-    email                : gunnar@schmi-dt.de
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002-2003 Jeff Roush <jeff@mousetool.com>
+    SPDX-FileCopyrightText: 2003 Olaf Schmidt <ojschmidt@kde.org>
+    SPDX-FileCopyrightText: 2003 Gunnar Schmi Dt <gunnar@schmi-dt.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kmousetool.h"
 
@@ -445,7 +431,6 @@ void KMouseTool::saveOptions()
     int y = p.y();
 
     KConfigGroup cfg = KSharedConfig::openConfig()->group("ProgramOptions");
-    cfg.writeEntry("Version", KMOUSETOOL_VERSION);
     cfg = KSharedConfig::openConfig()->group("UserOptions");
     cfg.writeEntry("x", x);
     cfg.writeEntry("y", y);
