@@ -1,23 +1,9 @@
-/***************************************************************************
-                          kmousetool.h  -  description
-                             -------------------
-    begin                : Sun Jan 20 23:27:58 PST 2002
-    copyright            : (C) 2002-2003 by Jeff Roush
-    email                : jeff@mousetool.com
-    copyright            : (C) 2003 by Olaf Schmidt
-    email                : ojschmidt@kde.org
-    copyright            : (C) 2003 by Gunnar Schmi Dt
-    email                : gunnar@schmi-dt.de
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002-2003 Jeff Roush <jeff@mousetool.com>
+    SPDX-FileCopyrightText: 2003 Olaf Schmidt <ojschmidt@kde.org>
+    SPDX-FileCopyrightText: 2003 Gunnar Schmi Dt <gunnar@schmi-dt.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KMOUSETOOL_H
 #define KMOUSETOOL_H
@@ -26,8 +12,6 @@
 #include <QTimerEvent>
 #include <QWidget>
 
-#include "version.h"
-
 #include <KStatusNotifierItem>
 #include "mtstroke.h"
 #include "ui_kmousetoolui.h"
@@ -174,7 +158,7 @@ public:
      * current mouse position to its previous position to see
      * whether to send a down click, and up click, or wait.
      */
-    void timerEvent (QTimerEvent *e) Q_DECL_OVERRIDE;
+    void timerEvent (QTimerEvent *e) override;
 
     /**
      * This generates a normal click event --
@@ -188,14 +172,14 @@ public:
     explicit KMouseTool(QWidget* parent=nullptr, const char *name=nullptr);
 
     /** destructor */
-    ~KMouseTool();
+    ~KMouseTool() override;
 };
 
 class KMouseToolTray : public KStatusNotifierItem {
     Q_OBJECT
 public:
     explicit KMouseToolTray (QWidget *parent=nullptr);
-    ~KMouseToolTray();
+    ~KMouseToolTray() override;
 
     void updateStartStopText (bool mousetool_is_running);
 Q_SIGNALS:
