@@ -1,21 +1,8 @@
-/***************************************************************************
-                          mtstroke.cpp  -  description
-                             -------------------
-    begin                : Fri Oct 11 2002
-    copyright            : (C) 2002 by Jeff Roush
-    email                : jeff@mousetool.com
-    copyright            : (C) 2003 by Olaf Schmidt
-    email                : ojschmidt@kde.org
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002 Jeff Roush <jeff@mousetool.com>
+    SPDX-FileCopyrightText: 2003 Olaf Schmidt <ojschmidt@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mtstroke.h"
 #include "kmousetool.h"
